# File: evm_OMEGACAMmain.tcl
# Purpose: OMEGACAM EVM main procedure
# Author: St�phane Marteau
#

# $Id: evm_OMEGACAMmain.tcl 303947 2017-11-29 10:30:52Z smarteau $

# Global variables
global scriptingBox
global OBdata keywordList Phase1data
global compoundList compoundListObjects

# Initialization of EVM process
set version [evmInit]

# Waivers: store values for evmWaiver array also in numerical format:
foreach idx [array names evmWaiver] {

    set evmWaiver([convertRunID $idx]) $evmWaiver($idx)

}

# List of keywords to retrieve + default values to assign in the code
# when they do not exist in the given template.
set keywordList { "SEQ.NEXPO" "" \
		      "TEL.TARG.OFFSETSIZEX" "" "TEL.TARG.OFFSETSIZEY" "" \
		      "TEL.TARG.PATTERN" "" "TEL.TARG.OFFSETSIZE" "" \
		      "TEL.TARG.OFFSETALPHA" "" "TEL.TARG.OFFSETDELTA" "" \
		      "TEL.TARG.ADDVELALPHA" "" "TEL.TARG.ADDVELDELTA" "" \
		      "TEL.ROT.OFFANGLE" "" "TEL.ADC.TYPE" "" "INS.FILT.NAME" "" \
		      "OCS.AG.START" "" "OCS.IA.START" "" "DET1.WIN1.UIT1" "" "SEQ.NEXPO" "" \
		      "TEL.TARG.DX" "" "TEL.TARG.DY" "" "SEQ.RET2ORIG" "" \
		  }


# Analyze selection of OBs + containers
# and parse all relevant OBs
retrieveAndParse

# Exception: if there are no OBs in the parsed material, exit
if { $OBdata(nbOBs) == 0 } { return }

# Collect Phase 1 info
collectPhase1Info

set OBdata(totalExecutionTime) 0


# Loop over all elements in the compound list
foreach object $compoundList {
	
    # Level 1 checks
    checkOMEGACAMLevel1 $object

    # Level 2 checks
    checkOMEGACAMLevel2 $object
    
    # Level 3 checks
    checkOMEGACAMLevel3 $object

}

# Check on the total allocated time

# Convert total execution time to hours
set OBdata(totalExecutionTime) [expr $OBdata(totalExecutionTime) / 3600.]

# For service mode, non-ToO runs: issue an error if the total execution time of the
# selected OBs exceeds the time allocated in the schedule

if { $Phase1data(isPublicSurvey) == 0 && $Phase1data(runMode) == "s" && \
	 $Phase1data(tooFlag) != 1 && $Phase1data(allocatedTime) > 0. && \
	 ( $OBdata(totalExecutionTime) > [expr $Phase1data(allocatedTime) * 1.03] || \
	       $OBdata(totalExecutionTime) > [expr $Phase1data(allocatedTime) + 0.25] ) } {
    
    set msg "\n******************************\n"
    append msg [format "The total execution time of the selected OB(s) exceeds the run time allocation (%.1f h) by %.1f hours.\n" $Phase1data(allocatedTime) [expr $OBdata(totalExecutionTime) - $Phase1data(allocatedTime)]]
    append msg "******************************\n\n"
    evmWarning $msg
    
}


# Display the summary table
displayEVMSummaryTable

evmInfo ""

# Display the final detailed report
displayEVMReport






